import React, { FocusEventHandler, MouseEventHandler, ReactNode } from 'react';
import { Props, StylesConfig } from 'react-select';
import { TooltipInfoProps } from '../TooltipInfo';
export interface internalSelectProps {
    selectProps: {
        onApplyClick: MouseEventHandler<HTMLButtonElement>;
        onCancelClick: MouseEventHandler<HTMLButtonElement>;
        onMenuInputFocus: FocusEventHandler<HTMLInputElement>;
        extraProps: {
            textFilter: string;
            setTextFilter: React.Dispatch<React.SetStateAction<string>>;
            isOptionsAddingEnabled: boolean;
            isCreatingOption: boolean;
            onCreateOption: (newOptionLabel: string) => Promise<optionType>;
            isComboBox: boolean;
        };
        isLoading: boolean;
        multiSelectProps: {
            optionName: string;
            isSummarizedLabel: boolean;
        };
    };
    selectOption?: Function;
    data?: optionType;
}
export interface optionType {
    value: string | number;
    label: string;
    label2: string;
    isDisabled: boolean;
    disabledTitle: string;
}
export interface SelectProps extends Props {
    /** select's type */
    variant: 'default' | 'underline' | 'inline' | 'two-lines';
    /** disabled state */
    isDisabled: boolean;
    /** custom classname */
    className: string;
    /** Field Label */
    label: string;
    /** Placeholder */
    placeholder: string;
    /** error text */
    error: string;
    /** warning text */
    warning: string;
    /** remove margin-bottom (to allow inline alignment) */
    isBottomMarginRemoved: boolean;
    /** options array */
    options: optionType[];
    /** selected option */
    value: optionType | optionType[];
    /** while loading options, should show loader */
    isLoading: boolean;
    /** allow search */
    isSearchable: boolean;
    /** info tooltip */
    info: ReactNode;
    /** InfoTooltip props */
    infoProps: TooltipInfoProps;
    /** can add values that are not in the options */
    isOptionsAddingEnabled: boolean;
    styles: StylesConfig;
    /** Is the field Readonly  */
    isReadOnly: boolean;
    /** Callback to be called when options selection change */
    onSelectionChanged: (selectedOptions: optionType[]) => void;
    /** while an option is creating, Should show a loader */
    isCreatingOption?: boolean;
    /** Handler for creating a new option. You should add the new option to options and return the new option.
     *  If there is no need for async actions. just return Promise.Resolved */
    onCreateOption?: (newOptionLabel: string) => Promise<optionType>;
    /** Default value for the select */
    defaultValue?: optionType[];
    /** Options for multi select and for combo box */
    multiSelectProps?: {
        /** if true, showing summarized selected options indication (6 clusters selected). if false, showing selected options one by one (as chips) */
        isSummarizedLabel?: boolean;
        /** When 'isSummarizedLabel' is true, showing the option name in the summary. For example "5 [optionNames] are selected" */
        optionName?: string;
        /** Should show 'apply' and 'cancel' buttons? if true, onSelectionChanged called only when pressing the button*/
        isComboBox?: boolean;
        /** Add 'Select All' option */
        isSelectAllAllowed?: boolean;
    };
    /** Is this field optional */
    isOptional?: boolean;
}
export declare const SelectField: (props: SelectProps) => JSX.Element;
