import { __assign } from 'tslib';
import { jsxs, jsx } from 'react/jsx-runtime';
import { useState } from 'react';
import styles from './TableTopBar.module.scss.js';
import { Typography } from '../Typography/index.js';
import classNames from 'classnames';
import { TooltipInfo } from '../TooltipInfo/index.js';
import { Button } from '../Button/index.js';
import { Parser } from '@json2csv/plainjs';
import { ReactComponent } from '@netapp/icons/ic_download.svg';
import _pick from 'lodash/pick';

var exportToCsv = function (_a, tableProps) {
  var fileName = _a.fileName,
    _b = _a.options,
    options = _b === void 0 ? {} : _b;
  var organizedRows = tableProps.organizedRows,
    columns = tableProps.columns;
  var selectedColumns = columns.map(function (column) {
    return column.accessor;
  }).filter(function (accessor) {
    return accessor;
  });
  var data = organizedRows.map(function (row) {
    return _pick(row, selectedColumns);
  });
  var parser = new Parser(options);
  var parsedData = parser.parse(data);
  var element = document.createElement('a');
  element.setAttribute('href', "data:text/plain;charset=utf-8,".concat(encodeURIComponent(parsedData)));
  element.setAttribute('download', fileName);
  element.style.display = 'none';
  document.body.appendChild(element);
  element.click();
  document.body.removeChild(element);
};
var TableTopBar = function (_a) {
  var tableProps = _a.tableProps,
    singularTitle = _a.singularTitle,
    pluralTitle = _a.pluralTitle,
    info = _a.info,
    className = _a.className,
    initialTextFilter = _a.initialTextFilter,
    actionsRight = _a.actionsRight,
    actionsLeft = _a.actionsLeft,
    exportToCsvOptions = _a.exportToCsvOptions;
  var organizedRows = tableProps.organizedRows;
    tableProps.updateTextFilter;
    var rows = tableProps.rows,
    filterState = tableProps.filterState,
    resetFilters = tableProps.resetFilters,
    selectionState = tableProps.selectionState;
    tableProps.pagination.pageRows;
  var _b = useState(initialTextFilter);
    _b[0];
    var setInputTextFilter = _b[1];
  var itemCount = rows.length;
  var filteredItemCount = organizedRows.length;
  var textFilter = filterState === null || filterState === void 0 ? void 0 : filterState.textFilter;
  var showFilterText = (filterState === null || filterState === void 0 ? void 0 : filterState.count) > 0 || textFilter;
  var showSelectionText = selectionState && (selectionState === null || selectionState === void 0 ? void 0 : selectionState.count) > 0;
  return jsxs("div", __assign({
    className: classNames(styles.base, className)
  }, {
    children: [jsxs(Typography, __assign({
      variant: 'Semibold_16',
      isEllipsis: true,
      className: styles.title
    }, {
      children: [jsx("span", {
        children: itemCount === 1 ? singularTitle : pluralTitle
      }), jsxs("span", {
        children: ["(", itemCount === filteredItemCount ? itemCount : filteredItemCount + '/' + itemCount, ")"]
      }), info && jsx(TooltipInfo, {
        children: info
      }), showFilterText && jsx("span", {
        children: "| Filtered by".concat(textFilter ? ' search' : '').concat(textFilter && (filterState === null || filterState === void 0 ? void 0 : filterState.count) > 0 ? ' & ' : '').concat((filterState === null || filterState === void 0 ? void 0 : filterState.count) ? " ".concat(filterState === null || filterState === void 0 ? void 0 : filterState.count, " parameter").concat((filterState === null || filterState === void 0 ? void 0 : filterState.count) > 1 ? 's' : '') : '')
      }), showSelectionText && jsx("span", {
        children: "| ".concat((selectionState === null || selectionState === void 0 ? void 0 : selectionState.count) === itemCount ? 'All selected' : "".concat(selectionState === null || selectionState === void 0 ? void 0 : selectionState.count, " selected"))
      }), showFilterText && jsx(Button, __assign({
        variant: 'text',
        onClick: function () {
          resetFilters();
          setInputTextFilter('');
        }
      }, {
        children: "Reset filters"
      }))]
    })), jsxs("div", __assign({
      className: styles.actions
    }, {
      children: [actionsLeft, exportToCsvOptions && jsx(Button, __assign({
        variant: 'icon',
        onClick: function () {
          return exportToCsv(exportToCsvOptions, tableProps);
        }
      }, {
        children: jsx(ReactComponent, {})
      })), actionsRight]
    }))]
  }));
};

export { TableTopBar, exportToCsv };
//# sourceMappingURL=TableTopBar.js.map
