import React, { Component, MouseEventHandler, ReactNode } from 'react';
import { TooltipInfoProps } from '../TooltipInfo';
import { HashTable } from '../../utils/types';
import { ColumnFilterStateType, ColumnStateType, FilterStateType, rowDataType, RowStateType, SortStateType } from './useTable';
export interface filterOptionShape {
    /** value the data should be filtered for */
    value: string | boolean | number;
    /** label of filter */
    label: string;
}
export interface RowMetaData {
    updateRowState: Function;
    rowState: RowStateType;
    isRowHovered: boolean;
}
export interface ColumnProps {
    /** Identifier for the column */
    id: string;
    /** column header label text/ react node/ React Function */
    Header: ReactNode | typeof React.Component;
    /** key of relevant property from data */
    accessor: string;
    /** Is column should be sortable */
    isSortable?: boolean;
    /** Is filterable? pass filter options or allow auto-creation of the options by passing 'auto'.  */
    filterOptions?: 'auto' | filterOptionShape[];
    /** informative tooltip on column header */
    info?: ReactNode;
    /** column width - valid grid template column value. required on horizontal scroll */
    width?: string;
    /** custom cell content (cellData,rowData)=>cellContent */
    renderCell?: (cellData: any, rowData: rowDataType, rowMetaData: RowMetaData) => ReactNode;
    /** custom filter-panel label content (val)=>labelContent */
    renderFilterPanelLabel?: Function;
    /** custom classname for the column. header and cells */
    className?: string;
    /** InfoTooltip props */
    infoProps?: TooltipInfoProps;
    /** On horizontal scroll, keep column sticky, can be apply to x first and x last columns */
    isSticky?: boolean;
    /** Property in the data to use for text filter purposes */
    accessorForTextFilter?: string;
    /** The filter state of the column */
    filterState?: ColumnFilterStateType;
    /** A callback to update column filter */
    updateColumnFilter?: Function;
    /** A callback to toggle the sort state of the column */
    toggleSort?: MouseEventHandler<HTMLButtonElement>;
    /** The sorting state of the column */
    columnSortState?: 'asc' | 'desc' | null;
}
export type SelectionStateType = {
    rows: HashTable<boolean>;
    count: number;
    allSelected?: boolean;
} | undefined;
export type PaginationStateType = {
    gotoPage: Function;
    pageIndex: number;
    pageRows: rowDataType[];
    pageCount: number;
    totalRows: number;
};
type TableStateType = any;
type PageStateType = any;
export interface TableProps {
    /** Is there horizontal scroll? if true, a fixed width should be given to each columns */
    isHorizontalScroll: boolean;
    /** All the rows of the table */
    rows: rowDataType[];
    /** Filtered and sorted rows */
    organizedRows: rowDataType[];
    /** The columns of the table */
    columns: ColumnProps[];
    /** The sorting state of the table */
    sortState: SortStateType;
    /** The filter state of the table */
    filterState: FilterStateType;
    /** The state of the table */
    tableState: TableStateType;
    /** The state of the row */
    rowState: HashTable<RowStateType>;
    /** The state of selection of rows */
    selectionState: SelectionStateType;
    /** The state of columns */
    columnState: HashTable<ColumnStateType>;
    /** A callback to toggle a column sorting state */
    toggleSort: Function;
    /** Update column filter state */
    updateFilterState: Function;
    /** Update specific row state */
    updateRowState: Function;
    /** Update text  filter (search) */
    updateTextFilter: Function;
    /** Update table selection */
    toggleRowSelection: Function;
    /** A callback to select all rows */
    selectAllRows: Function;
    /** A callback to remove all filters (including search) */
    resetFilters: Function;
    /** Info of pagination, when number of rows bigger than pageSize */
    pagination: PaginationStateType;
    /** Maximum rows per page */
    pageSize: number;
    /** The text filter string value(search) */
    textFilter: string;
    /** state of a specific page in the table */
    pageState: PageStateType;
    /** The initial pages state */
    initialPageState: PageStateType;
}
export interface TableComponentProps {
    /** The props of the table (returned from useTable hook) */
    tableProps: TableProps;
    /** Custom classname */
    className?: string;
    /** Should column auto sizing feature be disabled? */
    isColumnsAutoSizeDisabled?: boolean;
    /** Are there external Filters, if true, the filter buttons in the tables header will disappear */
    isExternalFilter?: boolean;
    /** In case the row is expandable, ExpandedRow will be the component that will render the expanded row */
    ExpandedRow?: typeof Component;
    /** Should row ne higher? (72px) */
    isDoubleRow?: boolean;
}
/** Data table - Should be used with useTable hook, all props go for useTable which return the gridProps (apart from className, isColumnsAutoSizeDisabled and isExternalFilter) */
export declare const Table: React.ForwardRefExoticComponent<TableComponentProps & React.RefAttributes<unknown>>;
export {};
